autowisp.processing_steps.lc_detrending module — AutoWISP documentation

# autowisp.processing_steps.lc_detrending module

## Class Inheritance Diagram

Functions for detrending light curves (EPD or TFA).

autowisp.processing_steps.lc_detrending._add_catalog_info(lc_fnames, catalog_sources, magnitude_expression, result=None)

  Fill the catalog information fields in result.

autowisp.processing_steps.lc_detrending.calculate_detrending_performance(lc_fnames, start_status, configuration, mark_progress, detrending_mode)

  Create a statistics file after de-trending directly from LCs.

  Parameters:

    - lc_fnames – Iterable over the filenames of the de-trended lightcurves to rederive the statistics for.

    - catalog_fname – The filename of the catalog to add information to the statistics.

    - magnitude_column – The column from the catalog to use as brightness indicator in the statistics file.

    - output_statistics_fname – The filename to save the statistics under.

    - recalc_arguments – Passed directly to recalculate_correction_statistics()

autowisp.processing_steps.lc_detrending.correct_target_lc(target_lc_fname, configuration, correct)

  Perform reconstructive detrending on the target LC.

autowisp.processing_steps.lc_detrending.detrend_light_curves(lc_collection, configuration, correct)

  Detrend all lightcurves and create statistics file.

autowisp.processing_steps.lc_detrending.extract_target_lc(lc_fnames, target_id)

  Return target LC fname, & LC fname list with the target LC removed.

autowisp.processing_steps.lc_detrending.get_transit_parameters(configuration, unwind_limb_darkening=True)

  Return the parameters to pass to pytransit model.